@@ -1,7 +1,7 @@
 """
 Type annotations for dynamodb service ServiceResource
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html)
+[Open documentation](./service_resource.md)
 
 Usage::
 
@@ -25,7 +25,7 @@ from boto3.dynamodb.table import BatchWriter
 from boto3.resources.base import ServiceResource as Boto3ServiceResource
 from boto3.resources.collection import ResourceCollection
 
-from mypy_boto3_dynamodb.literals import (
+from .literals import (
     BillingMode,
     ConditionalOperator,
     ReturnConsumedCapacity,
@@ -33,7 +33,7 @@ from mypy_boto3_dynamodb.literals import (
     ReturnValue,
     Select,
 )
-from mypy_boto3_dynamodb.type_defs import (
+from .type_defs import (
     AttributeDefinitionTypeDef,
     AttributeValueUpdateTypeDef,
     BatchGetItemOutputTypeDef,
@@ -65,8 +65,8 @@ __all__ = ("DynamoDBServiceResource", "Table", "ServiceResourceTablesCollection"
 
 class ServiceResourceTablesCollection(ResourceCollection):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/dynamodb.html#DynamoDB.ServiceResource.tables)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#serviceresourcetablescollection)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/dynamodb.html#DynamoDB.ServiceResource.tables)
+    [Show boto3-stubs documentation](./service_resource.md#serviceresourcetablescollection)
     """
 
     def all(self) -> "ServiceResourceTablesCollection":
@@ -92,7 +92,7 @@ class ServiceResourceTablesCollection(ResourceCollection):
 
 class Table(Boto3ServiceResource):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#table)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)[Show boto3-stubs documentation](./service_resource.md#table)
     """
 
     attribute_definitions: List[Any]
@@ -120,14 +120,14 @@ class Table(Boto3ServiceResource):
 
     def batch_writer(self, overwrite_by_pkeys: List[str] = None) -> BatchWriter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/dynamodb.html#DynamoDB.Table.batch_writer)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablebatch-writermethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/dynamodb.html#DynamoDB.Table.batch_writer)
+        [Show boto3-stubs documentation](./service_resource.md#tablebatch-writermethod)
         """
 
     def delete(self) -> DeleteTableOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/dynamodb.html#DynamoDB.Table.delete)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tabledeletemethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/dynamodb.html#DynamoDB.Table.delete)
+        [Show boto3-stubs documentation](./service_resource.md#tabledeletemethod)
         """
 
     def delete_item(
@@ -179,14 +179,14 @@ class Table(Boto3ServiceResource):
         ] = None,
     ) -> DeleteItemOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/dynamodb.html#DynamoDB.Table.delete_item)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tabledelete-itemmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/dynamodb.html#DynamoDB.Table.delete_item)
+        [Show boto3-stubs documentation](./service_resource.md#tabledelete-itemmethod)
         """
 
     def get_available_subresources(self) -> List[str]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/dynamodb.html#DynamoDB.Table.get_available_subresources)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableget-available-subresourcesmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/dynamodb.html#DynamoDB.Table.get_available_subresources)
+        [Show boto3-stubs documentation](./service_resource.md#tableget-available-subresourcesmethod)
         """
 
     def get_item(
@@ -217,14 +217,14 @@ class Table(Boto3ServiceResource):
         ExpressionAttributeNames: Dict[str, str] = None,
     ) -> GetItemOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/dynamodb.html#DynamoDB.Table.get_item)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableget-itemmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/dynamodb.html#DynamoDB.Table.get_item)
+        [Show boto3-stubs documentation](./service_resource.md#tableget-itemmethod)
         """
 
     def load(self) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/dynamodb.html#DynamoDB.Table.load)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableloadmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/dynamodb.html#DynamoDB.Table.load)
+        [Show boto3-stubs documentation](./service_resource.md#tableloadmethod)
         """
 
     def put_item(
@@ -276,8 +276,8 @@ class Table(Boto3ServiceResource):
         ] = None,
     ) -> PutItemOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/dynamodb.html#DynamoDB.Table.put_item)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableput-itemmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/dynamodb.html#DynamoDB.Table.put_item)
+        [Show boto3-stubs documentation](./service_resource.md#tableput-itemmethod)
         """
 
     def query(
@@ -336,14 +336,14 @@ class Table(Boto3ServiceResource):
         ] = None,
     ) -> QueryOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/dynamodb.html#DynamoDB.Table.query)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablequerymethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/dynamodb.html#DynamoDB.Table.query)
+        [Show boto3-stubs documentation](./service_resource.md#tablequerymethod)
         """
 
     def reload(self) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/dynamodb.html#DynamoDB.Table.reload)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablereloadmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/dynamodb.html#DynamoDB.Table.reload)
+        [Show boto3-stubs documentation](./service_resource.md#tablereloadmethod)
         """
 
     def scan(
@@ -401,8 +401,8 @@ class Table(Boto3ServiceResource):
         ConsistentRead: bool = None,
     ) -> ScanOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/dynamodb.html#DynamoDB.Table.scan)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablescanmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/dynamodb.html#DynamoDB.Table.scan)
+        [Show boto3-stubs documentation](./service_resource.md#tablescanmethod)
         """
 
     def update(
@@ -416,8 +416,8 @@ class Table(Boto3ServiceResource):
         ReplicaUpdates: List[ReplicationGroupUpdateTypeDef] = None,
     ) -> "_Table":
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/dynamodb.html#DynamoDB.Table.update)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableupdatemethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/dynamodb.html#DynamoDB.Table.update)
+        [Show boto3-stubs documentation](./service_resource.md#tableupdatemethod)
         """
 
     def update_item(
@@ -471,20 +471,20 @@ class Table(Boto3ServiceResource):
         ] = None,
     ) -> UpdateItemOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/dynamodb.html#DynamoDB.Table.update_item)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableupdate-itemmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/dynamodb.html#DynamoDB.Table.update_item)
+        [Show boto3-stubs documentation](./service_resource.md#tableupdate-itemmethod)
         """
 
     def wait_until_exists(self) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/dynamodb.html#DynamoDB.Table.wait_until_exists)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablewait-until-existsmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/dynamodb.html#DynamoDB.Table.wait_until_exists)
+        [Show boto3-stubs documentation](./service_resource.md#tablewait-until-existsmethod)
         """
 
     def wait_until_not_exists(self) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/dynamodb.html#DynamoDB.Table.wait_until_not_exists)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablewait-until-not-existsmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/dynamodb.html#DynamoDB.Table.wait_until_not_exists)
+        [Show boto3-stubs documentation](./service_resource.md#tablewait-until-not-existsmethod)
         """
 
 
@@ -493,15 +493,15 @@ _Table = Table
 
 class DynamoDBServiceResource(Boto3ServiceResource):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/dynamodb.html#DynamoDB.ServiceResource)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/dynamodb.html#DynamoDB.ServiceResource)[Show boto3-stubs documentation](./service_resource.md)
     """
 
     tables: ServiceResourceTablesCollection
 
     def Table(self, name: str) -> _Table:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#dynamodbserviceresourcetablemethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)
+        [Show boto3-stubs documentation](./service_resource.md#dynamodbserviceresourcetablemethod)
         """
 
     def batch_get_item(
@@ -510,8 +510,8 @@ class DynamoDBServiceResource(Boto3ServiceResource):
         ReturnConsumedCapacity: ReturnConsumedCapacity = None,
     ) -> BatchGetItemOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_get_item)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#dynamodbserviceresourcebatch-get-itemmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_get_item)
+        [Show boto3-stubs documentation](./service_resource.md#dynamodbserviceresourcebatch-get-itemmethod)
         """
 
     def batch_write_item(
@@ -521,8 +521,8 @@ class DynamoDBServiceResource(Boto3ServiceResource):
         ReturnItemCollectionMetrics: ReturnItemCollectionMetrics = None,
     ) -> BatchWriteItemOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_write_item)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#dynamodbserviceresourcebatch-write-itemmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_write_item)
+        [Show boto3-stubs documentation](./service_resource.md#dynamodbserviceresourcebatch-write-itemmethod)
         """
 
     def create_table(
@@ -539,12 +539,12 @@ class DynamoDBServiceResource(Boto3ServiceResource):
         Tags: List["TagTypeDef"] = None,
     ) -> _Table:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/dynamodb.html#DynamoDB.ServiceResource.create_table)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#dynamodbserviceresourcecreate-tablemethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/dynamodb.html#DynamoDB.ServiceResource.create_table)
+        [Show boto3-stubs documentation](./service_resource.md#dynamodbserviceresourcecreate-tablemethod)
         """
 
     def get_available_subresources(self) -> List[str]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/dynamodb.html#DynamoDB.ServiceResource.get_available_subresources)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#dynamodbserviceresourceget-available-subresourcesmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/dynamodb.html#DynamoDB.ServiceResource.get_available_subresources)
+        [Show boto3-stubs documentation](./service_resource.md#dynamodbserviceresourceget-available-subresourcesmethod)
         """
